data
====

Simply add data (i.e. non code files) to your package. This option provide a simple
method to add data to a package that's robust enough to handle any way of packaging.

Look at a :doc:`data_tutorial` for a way to use this option.

Modifications
-------------

.. raw:: html
    :file: modifications.html
